Documentation
¶
Index ¶
- func DataDatabricksShare_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func DataDatabricksShare_IsConstruct(x interface{}) *bool
- func DataDatabricksShare_IsTerraformDataSource(x interface{}) *bool
- func DataDatabricksShare_IsTerraformElement(x interface{}) *bool
- func DataDatabricksShare_TfResourceType() *string
- func NewDataDatabricksShareObjectList_Override(d DataDatabricksShareObjectList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewDataDatabricksShareObjectOutputReference_Override(d DataDatabricksShareObjectOutputReference, ...)
- func NewDataDatabricksShareObjectPartitionList_Override(d DataDatabricksShareObjectPartitionList, ...)
- func NewDataDatabricksShareObjectPartitionOutputReference_Override(d DataDatabricksShareObjectPartitionOutputReference, ...)
- func NewDataDatabricksShareObjectPartitionValueList_Override(d DataDatabricksShareObjectPartitionValueList, ...)
- func NewDataDatabricksShareObjectPartitionValueOutputReference_Override(d DataDatabricksShareObjectPartitionValueOutputReference, ...)
- func NewDataDatabricksShare_Override(d DataDatabricksShare, scope constructs.Construct, id *string, ...)
- type DataDatabricksShare
- type DataDatabricksShareConfig
- type DataDatabricksShareObject
- type DataDatabricksShareObjectList
- type DataDatabricksShareObjectOutputReference
- type DataDatabricksShareObjectPartition
- type DataDatabricksShareObjectPartitionList
- type DataDatabricksShareObjectPartitionOutputReference
- type DataDatabricksShareObjectPartitionValue
- type DataDatabricksShareObjectPartitionValueList
- type DataDatabricksShareObjectPartitionValueOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataDatabricksShare_GenerateConfigForImport ¶
func DataDatabricksShare_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a DataDatabricksShare resource upon running "cdktf plan <stack-name>".
func DataDatabricksShare_IsConstruct ¶
func DataDatabricksShare_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataDatabricksShare_IsTerraformDataSource ¶
func DataDatabricksShare_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataDatabricksShare_IsTerraformElement ¶
func DataDatabricksShare_IsTerraformElement(x interface{}) *bool
Experimental.
func DataDatabricksShare_TfResourceType ¶
func DataDatabricksShare_TfResourceType() *string
func NewDataDatabricksShareObjectList_Override ¶
func NewDataDatabricksShareObjectList_Override(d DataDatabricksShareObjectList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataDatabricksShareObjectOutputReference_Override ¶
func NewDataDatabricksShareObjectOutputReference_Override(d DataDatabricksShareObjectOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataDatabricksShareObjectPartitionList_Override ¶
func NewDataDatabricksShareObjectPartitionList_Override(d DataDatabricksShareObjectPartitionList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataDatabricksShareObjectPartitionOutputReference_Override ¶
func NewDataDatabricksShareObjectPartitionOutputReference_Override(d DataDatabricksShareObjectPartitionOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataDatabricksShareObjectPartitionValueList_Override ¶
func NewDataDatabricksShareObjectPartitionValueList_Override(d DataDatabricksShareObjectPartitionValueList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataDatabricksShareObjectPartitionValueOutputReference_Override ¶
func NewDataDatabricksShareObjectPartitionValueOutputReference_Override(d DataDatabricksShareObjectPartitionValueOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataDatabricksShare_Override ¶
func NewDataDatabricksShare_Override(d DataDatabricksShare, scope constructs.Construct, id *string, config *DataDatabricksShareConfig)
Create a new {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/data-sources/share databricks_share} Data Source.
Types ¶
type DataDatabricksShare ¶
type DataDatabricksShare interface {
cdktf.TerraformDataSource
CdktfStack() cdktf.TerraformStack
ConstructNodeMetadata() *map[string]interface{}
Count() interface{}
// Experimental.
DependsOn() *[]*string
SetDependsOn(val *[]*string)
ForEach() cdktf.ITerraformIterator
SetForEach(val cdktf.ITerraformIterator)
Fqn() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
// The tree node.
Provider() cdktf.TerraformProvider
SetProvider(val cdktf.TerraformProvider)
RawOverrides() interface{}
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
TerraformMetaArguments() *map[string]interface{}
TerraformResourceType() *string
AddOverride(path *string, value interface{})
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
GetListAttribute(terraformAttribute *string) *[]*string
GetNumberAttribute(terraformAttribute *string) *float64
GetNumberListAttribute(terraformAttribute *string) *[]*float64
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
GetStringAttribute(terraformAttribute *string) *string
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
// Experimental.
ToHclTerraform() interface{}
ToMetadata() interface{}
ToString() *string
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/data-sources/share databricks_share}.
func NewDataDatabricksShare ¶
func NewDataDatabricksShare(scope constructs.Construct, id *string, config *DataDatabricksShareConfig) DataDatabricksShare
Create a new {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/data-sources/share databricks_share} Data Source.
type DataDatabricksShareConfig ¶
type DataDatabricksShareConfig struct {
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
Count interface{} `field:"optional" json:"count" yaml:"count"`
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
CreatedAt *float64 `field:"optional" json:"createdAt" yaml:"createdAt"`
CreatedBy *string `field:"optional" json:"createdBy" yaml:"createdBy"`
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
Name *string `field:"optional" json:"name" yaml:"name"`
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/data-sources/share#object DataDatabricksShare#object}
Object interface{} `field:"optional" json:"object" yaml:"object"`
}
type DataDatabricksShareObject ¶
type DataDatabricksShareObject struct {
DataObjectType *string `field:"required" json:"dataObjectType" yaml:"dataObjectType"`
Name *string `field:"required" json:"name" yaml:"name"`
AddedAt *float64 `field:"optional" json:"addedAt" yaml:"addedAt"`
AddedBy *string `field:"optional" json:"addedBy" yaml:"addedBy"`
CdfEnabled interface{} `field:"optional" json:"cdfEnabled" yaml:"cdfEnabled"`
Comment *string `field:"optional" json:"comment" yaml:"comment"`
HistoryDataSharingStatus *string `field:"optional" json:"historyDataSharingStatus" yaml:"historyDataSharingStatus"`
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/data-sources/share#partition DataDatabricksShare#partition}
Partition interface{} `field:"optional" json:"partition" yaml:"partition"`
SharedAs *string `field:"optional" json:"sharedAs" yaml:"sharedAs"`
StartVersion *float64 `field:"optional" json:"startVersion" yaml:"startVersion"`
Status *string `field:"optional" json:"status" yaml:"status"`
}
type DataDatabricksShareObjectList ¶
type DataDatabricksShareObjectList interface {
cdktf.ComplexList
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
// The attribute on the parent resource this class is referencing.
// The parent resource.
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataDatabricksShareObjectList ¶
func NewDataDatabricksShareObjectList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataDatabricksShareObjectList
type DataDatabricksShareObjectOutputReference ¶
type DataDatabricksShareObjectOutputReference interface {
cdktf.ComplexObject
// Experimental.
ComplexObjectIndex() interface{}
SetComplexObjectIndex(val interface{})
// Experimental.
ComplexObjectIsFromSet() *bool
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
// Experimental.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
ComputeFqn() *string
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
GetListAttribute(terraformAttribute *string) *[]*string
GetNumberAttribute(terraformAttribute *string) *float64
GetNumberListAttribute(terraformAttribute *string) *[]*float64
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
GetStringAttribute(terraformAttribute *string) *string
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
InterpolationAsList() cdktf.IResolvable
// Experimental.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataDatabricksShareObjectOutputReference ¶
func NewDataDatabricksShareObjectOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataDatabricksShareObjectOutputReference
type DataDatabricksShareObjectPartition ¶
type DataDatabricksShareObjectPartition struct {
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/data-sources/share#value DataDatabricksShare#value}
Value interface{} `field:"required" json:"value" yaml:"value"`
}
type DataDatabricksShareObjectPartitionList ¶
type DataDatabricksShareObjectPartitionList interface {
cdktf.ComplexList
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
// The attribute on the parent resource this class is referencing.
// The parent resource.
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataDatabricksShareObjectPartitionList ¶
func NewDataDatabricksShareObjectPartitionList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataDatabricksShareObjectPartitionList
type DataDatabricksShareObjectPartitionOutputReference ¶
type DataDatabricksShareObjectPartitionOutputReference interface {
cdktf.ComplexObject
// Experimental.
ComplexObjectIndex() interface{}
SetComplexObjectIndex(val interface{})
// Experimental.
ComplexObjectIsFromSet() *bool
SetComplexObjectIsFromSet(val *bool)
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
ComputeFqn() *string
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
GetListAttribute(terraformAttribute *string) *[]*string
GetNumberAttribute(terraformAttribute *string) *float64
GetNumberListAttribute(terraformAttribute *string) *[]*float64
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
GetStringAttribute(terraformAttribute *string) *string
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
InterpolationAsList() cdktf.IResolvable
// Experimental.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataDatabricksShareObjectPartitionOutputReference ¶
func NewDataDatabricksShareObjectPartitionOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataDatabricksShareObjectPartitionOutputReference
type DataDatabricksShareObjectPartitionValue ¶
type DataDatabricksShareObjectPartitionValue struct {
Name *string `field:"required" json:"name" yaml:"name"`
Op *string `field:"required" json:"op" yaml:"op"`
RecipientPropertyKey *string `field:"optional" json:"recipientPropertyKey" yaml:"recipientPropertyKey"`
Value *string `field:"optional" json:"value" yaml:"value"`
}
type DataDatabricksShareObjectPartitionValueList ¶
type DataDatabricksShareObjectPartitionValueList interface {
cdktf.ComplexList
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
// The attribute on the parent resource this class is referencing.
// The parent resource.
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataDatabricksShareObjectPartitionValueList ¶
func NewDataDatabricksShareObjectPartitionValueList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataDatabricksShareObjectPartitionValueList
type DataDatabricksShareObjectPartitionValueOutputReference ¶
type DataDatabricksShareObjectPartitionValueOutputReference interface {
cdktf.ComplexObject
// Experimental.
ComplexObjectIndex() interface{}
SetComplexObjectIndex(val interface{})
// Experimental.
ComplexObjectIsFromSet() *bool
SetComplexObjectIsFromSet(val *bool)
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
ComputeFqn() *string
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
GetListAttribute(terraformAttribute *string) *[]*string
GetNumberAttribute(terraformAttribute *string) *float64
GetNumberListAttribute(terraformAttribute *string) *[]*float64
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
GetStringAttribute(terraformAttribute *string) *string
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
InterpolationAsList() cdktf.IResolvable
// Experimental.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataDatabricksShareObjectPartitionValueOutputReference ¶
func NewDataDatabricksShareObjectPartitionValueOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataDatabricksShareObjectPartitionValueOutputReference
Source Files
¶
- DataDatabricksShare.go
- DataDatabricksShareConfig.go
- DataDatabricksShareObject.go
- DataDatabricksShareObjectList.go
- DataDatabricksShareObjectList__checks.go
- DataDatabricksShareObjectOutputReference.go
- DataDatabricksShareObjectOutputReference__checks.go
- DataDatabricksShareObjectPartition.go
- DataDatabricksShareObjectPartitionList.go
- DataDatabricksShareObjectPartitionList__checks.go
- DataDatabricksShareObjectPartitionOutputReference.go
- DataDatabricksShareObjectPartitionOutputReference__checks.go
- DataDatabricksShareObjectPartitionValue.go
- DataDatabricksShareObjectPartitionValueList.go
- DataDatabricksShareObjectPartitionValueList__checks.go
- DataDatabricksShareObjectPartitionValueOutputReference.go
- DataDatabricksShareObjectPartitionValueOutputReference__checks.go
- DataDatabricksShare__checks.go
- main.go