Documentation
¶
Index ¶
- func Entitlements_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func Entitlements_IsConstruct(x interface{}) *bool
- func Entitlements_IsTerraformElement(x interface{}) *bool
- func Entitlements_IsTerraformResource(x interface{}) *bool
- func Entitlements_TfResourceType() *string
- func NewEntitlements_Override(e Entitlements, scope constructs.Construct, id *string, ...)
- type Entitlements
- type EntitlementsConfig
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Entitlements_GenerateConfigForImport ¶
func Entitlements_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a Entitlements resource upon running "cdktf plan <stack-name>".
func Entitlements_IsConstruct ¶
func Entitlements_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func Entitlements_IsTerraformElement ¶
func Entitlements_IsTerraformElement(x interface{}) *bool
Experimental.
func Entitlements_IsTerraformResource ¶
func Entitlements_IsTerraformResource(x interface{}) *bool
Experimental.
func Entitlements_TfResourceType ¶
func Entitlements_TfResourceType() *string
func NewEntitlements_Override ¶
func NewEntitlements_Override(e Entitlements, scope constructs.Construct, id *string, config *EntitlementsConfig)
Create a new {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/entitlements databricks_entitlements} Resource.
Types ¶
type Entitlements ¶
type Entitlements interface {
cdktf.TerraformResource
AllowClusterCreate() interface{}
SetAllowClusterCreate(val interface{})
AllowClusterCreateInput() interface{}
AllowInstancePoolCreate() interface{}
SetAllowInstancePoolCreate(val interface{})
AllowInstancePoolCreateInput() interface{}
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
DatabricksSqlAccess() interface{}
SetDatabricksSqlAccess(val interface{})
DatabricksSqlAccessInput() interface{}
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
GroupId() *string
SetGroupId(val *string)
GroupIdInput() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
ServicePrincipalId() *string
SetServicePrincipalId(val *string)
ServicePrincipalIdInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
UserId() *string
SetUserId(val *string)
UserIdInput() *string
WorkspaceAccess() interface{}
SetWorkspaceAccess(val interface{})
WorkspaceAccessInput() interface{}
// Adds a user defined moveTarget string to this resource to be later used in .moveTo(moveTarget) to resolve the location of the move.
// Experimental.
AddMoveTarget(moveTarget *string)
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
HasResourceMove() interface{}
// Experimental.
ImportFrom(id *string, provider cdktf.TerraformProvider)
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Move the resource corresponding to "id" to this resource.
//
// Note that the resource being moved from must be marked as moved using it's instance function.
// Experimental.
MoveFromId(id *string)
// Moves this resource to the target resource given by moveTarget.
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Moves this resource to the resource corresponding to "id".
// Experimental.
MoveToId(id *string)
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetAllowClusterCreate()
ResetAllowInstancePoolCreate()
ResetDatabricksSqlAccess()
ResetGroupId()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetServicePrincipalId()
ResetUserId()
ResetWorkspaceAccess()
SynthesizeAttributes() *map[string]interface{}
SynthesizeHclAttributes() *map[string]interface{}
// Experimental.
ToHclTerraform() interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/entitlements databricks_entitlements}.
func NewEntitlements ¶
func NewEntitlements(scope constructs.Construct, id *string, config *EntitlementsConfig) Entitlements
Create a new {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/entitlements databricks_entitlements} Resource.
type EntitlementsConfig ¶
type EntitlementsConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/entitlements#allow_cluster_create Entitlements#allow_cluster_create}.
AllowClusterCreate interface{} `field:"optional" json:"allowClusterCreate" yaml:"allowClusterCreate"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/entitlements#allow_instance_pool_create Entitlements#allow_instance_pool_create}.
AllowInstancePoolCreate interface{} `field:"optional" json:"allowInstancePoolCreate" yaml:"allowInstancePoolCreate"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/entitlements#databricks_sql_access Entitlements#databricks_sql_access}.
DatabricksSqlAccess interface{} `field:"optional" json:"databricksSqlAccess" yaml:"databricksSqlAccess"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/entitlements#group_id Entitlements#group_id}.
GroupId *string `field:"optional" json:"groupId" yaml:"groupId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/entitlements#id Entitlements#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/entitlements#service_principal_id Entitlements#service_principal_id}.
ServicePrincipalId *string `field:"optional" json:"servicePrincipalId" yaml:"servicePrincipalId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/entitlements#user_id Entitlements#user_id}.
UserId *string `field:"optional" json:"userId" yaml:"userId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/entitlements#workspace_access Entitlements#workspace_access}.
WorkspaceAccess interface{} `field:"optional" json:"workspaceAccess" yaml:"workspaceAccess"`
}