Documentation
¶
Index ¶
- func Library_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func Library_IsConstruct(x interface{}) *bool
- func Library_IsTerraformElement(x interface{}) *bool
- func Library_IsTerraformResource(x interface{}) *bool
- func Library_TfResourceType() *string
- func NewLibraryCranList_Override(l LibraryCranList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewLibraryCranOutputReference_Override(l LibraryCranOutputReference, terraformResource cdktf.IInterpolatingParent, ...)
- func NewLibraryMavenList_Override(l LibraryMavenList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewLibraryMavenOutputReference_Override(l LibraryMavenOutputReference, terraformResource cdktf.IInterpolatingParent, ...)
- func NewLibraryPypiList_Override(l LibraryPypiList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewLibraryPypiOutputReference_Override(l LibraryPypiOutputReference, terraformResource cdktf.IInterpolatingParent, ...)
- func NewLibrary_Override(l Library, scope constructs.Construct, id *string, config *LibraryConfig)
- type Library
- type LibraryConfig
- type LibraryCran
- type LibraryCranList
- type LibraryCranOutputReference
- type LibraryMaven
- type LibraryMavenList
- type LibraryMavenOutputReference
- type LibraryPypi
- type LibraryPypiList
- type LibraryPypiOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Library_GenerateConfigForImport ¶
func Library_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a Library resource upon running "cdktf plan <stack-name>".
func Library_IsConstruct ¶
func Library_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func Library_IsTerraformElement ¶
func Library_IsTerraformElement(x interface{}) *bool
Experimental.
func Library_IsTerraformResource ¶
func Library_IsTerraformResource(x interface{}) *bool
Experimental.
func Library_TfResourceType ¶
func Library_TfResourceType() *string
func NewLibraryCranList_Override ¶ added in v13.22.0
func NewLibraryCranList_Override(l LibraryCranList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewLibraryCranOutputReference_Override ¶
func NewLibraryCranOutputReference_Override(l LibraryCranOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewLibraryMavenList_Override ¶ added in v13.22.0
func NewLibraryMavenList_Override(l LibraryMavenList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewLibraryMavenOutputReference_Override ¶
func NewLibraryMavenOutputReference_Override(l LibraryMavenOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewLibraryPypiList_Override ¶ added in v13.22.0
func NewLibraryPypiList_Override(l LibraryPypiList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewLibraryPypiOutputReference_Override ¶
func NewLibraryPypiOutputReference_Override(l LibraryPypiOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewLibrary_Override ¶
func NewLibrary_Override(l Library, scope constructs.Construct, id *string, config *LibraryConfig)
Create a new {@link https://registry.terraform.io/providers/databricks/databricks/1.81.1/docs/resources/library databricks_library} Resource.
Types ¶
type Library ¶
type Library interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
ClusterId() *string
SetClusterId(val *string)
ClusterIdInput() *string
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
Cran() LibraryCranList
CranInput() interface{}
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Egg() *string
SetEgg(val *string)
EggInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
Jar() *string
SetJar(val *string)
JarInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Maven() LibraryMavenList
MavenInput() interface{}
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
Pypi() LibraryPypiList
PypiInput() interface{}
// Experimental.
RawOverrides() interface{}
Requirements() *string
SetRequirements(val *string)
RequirementsInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Whl() *string
SetWhl(val *string)
WhlInput() *string
// Adds a user defined moveTarget string to this resource to be later used in .moveTo(moveTarget) to resolve the location of the move.
// Experimental.
AddMoveTarget(moveTarget *string)
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
HasResourceMove() interface{}
// Experimental.
ImportFrom(id *string, provider cdktf.TerraformProvider)
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Move the resource corresponding to "id" to this resource.
//
// Note that the resource being moved from must be marked as moved using it's instance function.
// Experimental.
MoveFromId(id *string)
// Moves this resource to the target resource given by moveTarget.
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Moves this resource to the resource corresponding to "id".
// Experimental.
MoveToId(id *string)
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutCran(value interface{})
PutMaven(value interface{})
PutPypi(value interface{})
ResetCran()
ResetEgg()
ResetId()
ResetJar()
ResetMaven()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetPypi()
ResetRequirements()
ResetWhl()
SynthesizeAttributes() *map[string]interface{}
SynthesizeHclAttributes() *map[string]interface{}
// Experimental.
ToHclTerraform() interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/databricks/databricks/1.81.1/docs/resources/library databricks_library}.
func NewLibrary ¶
func NewLibrary(scope constructs.Construct, id *string, config *LibraryConfig) Library
Create a new {@link https://registry.terraform.io/providers/databricks/databricks/1.81.1/docs/resources/library databricks_library} Resource.
type LibraryConfig ¶
type LibraryConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.81.1/docs/resources/library#cluster_id Library#cluster_id}.
ClusterId *string `field:"required" json:"clusterId" yaml:"clusterId"`
// cran block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.81.1/docs/resources/library#cran Library#cran}
Cran interface{} `field:"optional" json:"cran" yaml:"cran"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.81.1/docs/resources/library#egg Library#egg}.
Egg *string `field:"optional" json:"egg" yaml:"egg"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.81.1/docs/resources/library#id Library#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.81.1/docs/resources/library#jar Library#jar}.
Jar *string `field:"optional" json:"jar" yaml:"jar"`
// maven block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.81.1/docs/resources/library#maven Library#maven}
Maven interface{} `field:"optional" json:"maven" yaml:"maven"`
// pypi block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.81.1/docs/resources/library#pypi Library#pypi}
Pypi interface{} `field:"optional" json:"pypi" yaml:"pypi"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.81.1/docs/resources/library#requirements Library#requirements}.
Requirements *string `field:"optional" json:"requirements" yaml:"requirements"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.81.1/docs/resources/library#whl Library#whl}.
Whl *string `field:"optional" json:"whl" yaml:"whl"`
}
type LibraryCran ¶
type LibraryCran struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.81.1/docs/resources/library#package Library#package}.
Package *string `field:"required" json:"package" yaml:"package"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.81.1/docs/resources/library#repo Library#repo}.
Repo *string `field:"optional" json:"repo" yaml:"repo"`
}
type LibraryCranList ¶ added in v13.22.0
type LibraryCranList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) LibraryCranOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLibraryCranList ¶ added in v13.22.0
func NewLibraryCranList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) LibraryCranList
type LibraryCranOutputReference ¶
type LibraryCranOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Package() *string
SetPackage(val *string)
PackageInput() *string
Repo() *string
SetRepo(val *string)
RepoInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetRepo()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLibraryCranOutputReference ¶
func NewLibraryCranOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) LibraryCranOutputReference
type LibraryMaven ¶
type LibraryMaven struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.81.1/docs/resources/library#coordinates Library#coordinates}.
Coordinates *string `field:"required" json:"coordinates" yaml:"coordinates"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.81.1/docs/resources/library#exclusions Library#exclusions}.
Exclusions *[]*string `field:"optional" json:"exclusions" yaml:"exclusions"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.81.1/docs/resources/library#repo Library#repo}.
Repo *string `field:"optional" json:"repo" yaml:"repo"`
}
type LibraryMavenList ¶ added in v13.22.0
type LibraryMavenList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) LibraryMavenOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLibraryMavenList ¶ added in v13.22.0
func NewLibraryMavenList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) LibraryMavenList
type LibraryMavenOutputReference ¶
type LibraryMavenOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Coordinates() *string
SetCoordinates(val *string)
CoordinatesInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Exclusions() *[]*string
SetExclusions(val *[]*string)
ExclusionsInput() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Repo() *string
SetRepo(val *string)
RepoInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetExclusions()
ResetRepo()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLibraryMavenOutputReference ¶
func NewLibraryMavenOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) LibraryMavenOutputReference
type LibraryPypi ¶
type LibraryPypi struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.81.1/docs/resources/library#package Library#package}.
Package *string `field:"required" json:"package" yaml:"package"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.81.1/docs/resources/library#repo Library#repo}.
Repo *string `field:"optional" json:"repo" yaml:"repo"`
}
type LibraryPypiList ¶ added in v13.22.0
type LibraryPypiList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) LibraryPypiOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLibraryPypiList ¶ added in v13.22.0
func NewLibraryPypiList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) LibraryPypiList
type LibraryPypiOutputReference ¶
type LibraryPypiOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Package() *string
SetPackage(val *string)
PackageInput() *string
Repo() *string
SetRepo(val *string)
RepoInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetRepo()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLibraryPypiOutputReference ¶
func NewLibraryPypiOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) LibraryPypiOutputReference
Source Files
¶
- Library.go
- LibraryConfig.go
- LibraryCran.go
- LibraryCranList.go
- LibraryCranList__checks.go
- LibraryCranOutputReference.go
- LibraryCranOutputReference__checks.go
- LibraryMaven.go
- LibraryMavenList.go
- LibraryMavenList__checks.go
- LibraryMavenOutputReference.go
- LibraryMavenOutputReference__checks.go
- LibraryPypi.go
- LibraryPypiList.go
- LibraryPypiList__checks.go
- LibraryPypiOutputReference.go
- LibraryPypiOutputReference__checks.go
- Library__checks.go
- main.go