Documentation
¶
Index ¶
- func MwsNetworks_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func MwsNetworks_IsConstruct(x interface{}) *bool
- func MwsNetworks_IsTerraformElement(x interface{}) *bool
- func MwsNetworks_IsTerraformResource(x interface{}) *bool
- func MwsNetworks_TfResourceType() *string
- func NewMwsNetworksErrorMessagesList_Override(m MwsNetworksErrorMessagesList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewMwsNetworksErrorMessagesOutputReference_Override(m MwsNetworksErrorMessagesOutputReference, ...)
- func NewMwsNetworksGcpNetworkInfoOutputReference_Override(m MwsNetworksGcpNetworkInfoOutputReference, ...)
- func NewMwsNetworksVpcEndpointsOutputReference_Override(m MwsNetworksVpcEndpointsOutputReference, ...)
- func NewMwsNetworks_Override(m MwsNetworks, scope constructs.Construct, id *string, ...)
- type MwsNetworks
- type MwsNetworksConfig
- type MwsNetworksErrorMessages
- type MwsNetworksErrorMessagesList
- type MwsNetworksErrorMessagesOutputReference
- type MwsNetworksGcpNetworkInfo
- type MwsNetworksGcpNetworkInfoOutputReference
- type MwsNetworksVpcEndpoints
- type MwsNetworksVpcEndpointsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func MwsNetworks_GenerateConfigForImport ¶
func MwsNetworks_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a MwsNetworks resource upon running "cdktf plan <stack-name>".
func MwsNetworks_IsConstruct ¶
func MwsNetworks_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func MwsNetworks_IsTerraformElement ¶
func MwsNetworks_IsTerraformElement(x interface{}) *bool
Experimental.
func MwsNetworks_IsTerraformResource ¶
func MwsNetworks_IsTerraformResource(x interface{}) *bool
Experimental.
func MwsNetworks_TfResourceType ¶
func MwsNetworks_TfResourceType() *string
func NewMwsNetworksErrorMessagesList_Override ¶
func NewMwsNetworksErrorMessagesList_Override(m MwsNetworksErrorMessagesList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewMwsNetworksErrorMessagesOutputReference_Override ¶
func NewMwsNetworksErrorMessagesOutputReference_Override(m MwsNetworksErrorMessagesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewMwsNetworksGcpNetworkInfoOutputReference_Override ¶
func NewMwsNetworksGcpNetworkInfoOutputReference_Override(m MwsNetworksGcpNetworkInfoOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewMwsNetworksVpcEndpointsOutputReference_Override ¶
func NewMwsNetworksVpcEndpointsOutputReference_Override(m MwsNetworksVpcEndpointsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewMwsNetworks_Override ¶
func NewMwsNetworks_Override(m MwsNetworks, scope constructs.Construct, id *string, config *MwsNetworksConfig)
Create a new {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/mws_networks databricks_mws_networks} Resource.
Types ¶
type MwsNetworks ¶
type MwsNetworks interface {
cdktf.TerraformResource
AccountId() *string
SetAccountId(val *string)
AccountIdInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CreationTime() *float64
SetCreationTime(val *float64)
CreationTimeInput() *float64
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
ErrorMessages() MwsNetworksErrorMessagesList
ErrorMessagesInput() interface{}
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
GcpNetworkInfo() MwsNetworksGcpNetworkInfoOutputReference
GcpNetworkInfoInput() *MwsNetworksGcpNetworkInfo
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
NetworkId() *string
SetNetworkId(val *string)
NetworkIdInput() *string
NetworkName() *string
SetNetworkName(val *string)
NetworkNameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
SecurityGroupIds() *[]*string
SetSecurityGroupIds(val *[]*string)
SecurityGroupIdsInput() *[]*string
SubnetIds() *[]*string
SetSubnetIds(val *[]*string)
SubnetIdsInput() *[]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
VpcEndpoints() MwsNetworksVpcEndpointsOutputReference
VpcEndpointsInput() *MwsNetworksVpcEndpoints
VpcId() *string
SetVpcId(val *string)
VpcIdInput() *string
VpcStatus() *string
SetVpcStatus(val *string)
VpcStatusInput() *string
WorkspaceId() *float64
SetWorkspaceId(val *float64)
WorkspaceIdInput() *float64
// Adds a user defined moveTarget string to this resource to be later used in .moveTo(moveTarget) to resolve the location of the move.
// Experimental.
AddMoveTarget(moveTarget *string)
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
HasResourceMove() interface{}
// Experimental.
ImportFrom(id *string, provider cdktf.TerraformProvider)
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Move the resource corresponding to "id" to this resource.
//
// Note that the resource being moved from must be marked as moved using it's instance function.
// Experimental.
MoveFromId(id *string)
// Moves this resource to the target resource given by moveTarget.
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Moves this resource to the resource corresponding to "id".
// Experimental.
MoveToId(id *string)
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutErrorMessages(value interface{})
PutGcpNetworkInfo(value *MwsNetworksGcpNetworkInfo)
PutVpcEndpoints(value *MwsNetworksVpcEndpoints)
ResetCreationTime()
ResetErrorMessages()
ResetGcpNetworkInfo()
ResetId()
ResetNetworkId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetSecurityGroupIds()
ResetSubnetIds()
ResetVpcEndpoints()
ResetVpcId()
ResetVpcStatus()
ResetWorkspaceId()
SynthesizeAttributes() *map[string]interface{}
SynthesizeHclAttributes() *map[string]interface{}
// Experimental.
ToHclTerraform() interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/mws_networks databricks_mws_networks}.
func NewMwsNetworks ¶
func NewMwsNetworks(scope constructs.Construct, id *string, config *MwsNetworksConfig) MwsNetworks
Create a new {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/mws_networks databricks_mws_networks} Resource.
type MwsNetworksConfig ¶
type MwsNetworksConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/mws_networks#account_id MwsNetworks#account_id}.
AccountId *string `field:"required" json:"accountId" yaml:"accountId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/mws_networks#network_name MwsNetworks#network_name}.
NetworkName *string `field:"required" json:"networkName" yaml:"networkName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/mws_networks#creation_time MwsNetworks#creation_time}.
CreationTime *float64 `field:"optional" json:"creationTime" yaml:"creationTime"`
// error_messages block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/mws_networks#error_messages MwsNetworks#error_messages}
ErrorMessages interface{} `field:"optional" json:"errorMessages" yaml:"errorMessages"`
// gcp_network_info block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/mws_networks#gcp_network_info MwsNetworks#gcp_network_info}
GcpNetworkInfo *MwsNetworksGcpNetworkInfo `field:"optional" json:"gcpNetworkInfo" yaml:"gcpNetworkInfo"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/mws_networks#id MwsNetworks#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/mws_networks#network_id MwsNetworks#network_id}.
NetworkId *string `field:"optional" json:"networkId" yaml:"networkId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/mws_networks#security_group_ids MwsNetworks#security_group_ids}.
SecurityGroupIds *[]*string `field:"optional" json:"securityGroupIds" yaml:"securityGroupIds"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/mws_networks#subnet_ids MwsNetworks#subnet_ids}.
SubnetIds *[]*string `field:"optional" json:"subnetIds" yaml:"subnetIds"`
// vpc_endpoints block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/mws_networks#vpc_endpoints MwsNetworks#vpc_endpoints}
VpcEndpoints *MwsNetworksVpcEndpoints `field:"optional" json:"vpcEndpoints" yaml:"vpcEndpoints"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/mws_networks#vpc_id MwsNetworks#vpc_id}.
VpcId *string `field:"optional" json:"vpcId" yaml:"vpcId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/mws_networks#vpc_status MwsNetworks#vpc_status}.
VpcStatus *string `field:"optional" json:"vpcStatus" yaml:"vpcStatus"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/mws_networks#workspace_id MwsNetworks#workspace_id}.
WorkspaceId *float64 `field:"optional" json:"workspaceId" yaml:"workspaceId"`
}
type MwsNetworksErrorMessages ¶
type MwsNetworksErrorMessages struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/mws_networks#error_message MwsNetworks#error_message}.
ErrorMessage *string `field:"optional" json:"errorMessage" yaml:"errorMessage"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/mws_networks#error_type MwsNetworks#error_type}.
ErrorType *string `field:"optional" json:"errorType" yaml:"errorType"`
}
type MwsNetworksErrorMessagesList ¶
type MwsNetworksErrorMessagesList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) MwsNetworksErrorMessagesOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewMwsNetworksErrorMessagesList ¶
func NewMwsNetworksErrorMessagesList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) MwsNetworksErrorMessagesList
type MwsNetworksErrorMessagesOutputReference ¶
type MwsNetworksErrorMessagesOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
ErrorMessage() *string
SetErrorMessage(val *string)
ErrorMessageInput() *string
ErrorType() *string
SetErrorType(val *string)
ErrorTypeInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetErrorMessage()
ResetErrorType()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewMwsNetworksErrorMessagesOutputReference ¶
func NewMwsNetworksErrorMessagesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) MwsNetworksErrorMessagesOutputReference
type MwsNetworksGcpNetworkInfo ¶
type MwsNetworksGcpNetworkInfo struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/mws_networks#network_project_id MwsNetworks#network_project_id}.
NetworkProjectId *string `field:"required" json:"networkProjectId" yaml:"networkProjectId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/mws_networks#pod_ip_range_name MwsNetworks#pod_ip_range_name}.
PodIpRangeName *string `field:"required" json:"podIpRangeName" yaml:"podIpRangeName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/mws_networks#service_ip_range_name MwsNetworks#service_ip_range_name}.
ServiceIpRangeName *string `field:"required" json:"serviceIpRangeName" yaml:"serviceIpRangeName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/mws_networks#subnet_id MwsNetworks#subnet_id}.
SubnetId *string `field:"required" json:"subnetId" yaml:"subnetId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/mws_networks#subnet_region MwsNetworks#subnet_region}.
SubnetRegion *string `field:"required" json:"subnetRegion" yaml:"subnetRegion"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/mws_networks#vpc_id MwsNetworks#vpc_id}.
VpcId *string `field:"required" json:"vpcId" yaml:"vpcId"`
}
type MwsNetworksGcpNetworkInfoOutputReference ¶
type MwsNetworksGcpNetworkInfoOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *MwsNetworksGcpNetworkInfo
SetInternalValue(val *MwsNetworksGcpNetworkInfo)
NetworkProjectId() *string
SetNetworkProjectId(val *string)
NetworkProjectIdInput() *string
PodIpRangeName() *string
SetPodIpRangeName(val *string)
PodIpRangeNameInput() *string
ServiceIpRangeName() *string
SetServiceIpRangeName(val *string)
ServiceIpRangeNameInput() *string
SubnetId() *string
SetSubnetId(val *string)
SubnetIdInput() *string
SubnetRegion() *string
SetSubnetRegion(val *string)
SubnetRegionInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
VpcId() *string
SetVpcId(val *string)
VpcIdInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewMwsNetworksGcpNetworkInfoOutputReference ¶
func NewMwsNetworksGcpNetworkInfoOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) MwsNetworksGcpNetworkInfoOutputReference
type MwsNetworksVpcEndpoints ¶
type MwsNetworksVpcEndpoints struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/mws_networks#dataplane_relay MwsNetworks#dataplane_relay}.
DataplaneRelay *[]*string `field:"required" json:"dataplaneRelay" yaml:"dataplaneRelay"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/mws_networks#rest_api MwsNetworks#rest_api}.
RestApi *[]*string `field:"required" json:"restApi" yaml:"restApi"`
}
type MwsNetworksVpcEndpointsOutputReference ¶
type MwsNetworksVpcEndpointsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DataplaneRelay() *[]*string
SetDataplaneRelay(val *[]*string)
DataplaneRelayInput() *[]*string
// Experimental.
Fqn() *string
InternalValue() *MwsNetworksVpcEndpoints
SetInternalValue(val *MwsNetworksVpcEndpoints)
RestApi() *[]*string
SetRestApi(val *[]*string)
RestApiInput() *[]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewMwsNetworksVpcEndpointsOutputReference ¶
func NewMwsNetworksVpcEndpointsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) MwsNetworksVpcEndpointsOutputReference
Source Files
¶
- MwsNetworks.go
- MwsNetworksConfig.go
- MwsNetworksErrorMessages.go
- MwsNetworksErrorMessagesList.go
- MwsNetworksErrorMessagesList__checks.go
- MwsNetworksErrorMessagesOutputReference.go
- MwsNetworksErrorMessagesOutputReference__checks.go
- MwsNetworksGcpNetworkInfo.go
- MwsNetworksGcpNetworkInfoOutputReference.go
- MwsNetworksGcpNetworkInfoOutputReference__checks.go
- MwsNetworksVpcEndpoints.go
- MwsNetworksVpcEndpointsOutputReference.go
- MwsNetworksVpcEndpointsOutputReference__checks.go
- MwsNetworks__checks.go
- main.go