Documentation
¶
Index ¶
- func NewVectorSearchEndpointEndpointStatusList_Override(v VectorSearchEndpointEndpointStatusList, ...)
- func NewVectorSearchEndpointEndpointStatusOutputReference_Override(v VectorSearchEndpointEndpointStatusOutputReference, ...)
- func NewVectorSearchEndpointTimeoutsOutputReference_Override(v VectorSearchEndpointTimeoutsOutputReference, ...)
- func NewVectorSearchEndpoint_Override(v VectorSearchEndpoint, scope constructs.Construct, id *string, ...)
- func VectorSearchEndpoint_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func VectorSearchEndpoint_IsConstruct(x interface{}) *bool
- func VectorSearchEndpoint_IsTerraformElement(x interface{}) *bool
- func VectorSearchEndpoint_IsTerraformResource(x interface{}) *bool
- func VectorSearchEndpoint_TfResourceType() *string
- type VectorSearchEndpoint
- type VectorSearchEndpointConfig
- type VectorSearchEndpointEndpointStatus
- type VectorSearchEndpointEndpointStatusList
- type VectorSearchEndpointEndpointStatusOutputReference
- type VectorSearchEndpointTimeouts
- type VectorSearchEndpointTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewVectorSearchEndpointEndpointStatusList_Override ¶
func NewVectorSearchEndpointEndpointStatusList_Override(v VectorSearchEndpointEndpointStatusList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewVectorSearchEndpointEndpointStatusOutputReference_Override ¶
func NewVectorSearchEndpointEndpointStatusOutputReference_Override(v VectorSearchEndpointEndpointStatusOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewVectorSearchEndpointTimeoutsOutputReference_Override ¶
func NewVectorSearchEndpointTimeoutsOutputReference_Override(v VectorSearchEndpointTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewVectorSearchEndpoint_Override ¶
func NewVectorSearchEndpoint_Override(v VectorSearchEndpoint, scope constructs.Construct, id *string, config *VectorSearchEndpointConfig)
Create a new {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/vector_search_endpoint databricks_vector_search_endpoint} Resource.
func VectorSearchEndpoint_GenerateConfigForImport ¶
func VectorSearchEndpoint_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a VectorSearchEndpoint resource upon running "cdktf plan <stack-name>".
func VectorSearchEndpoint_IsConstruct ¶
func VectorSearchEndpoint_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func VectorSearchEndpoint_IsTerraformElement ¶
func VectorSearchEndpoint_IsTerraformElement(x interface{}) *bool
Experimental.
func VectorSearchEndpoint_IsTerraformResource ¶
func VectorSearchEndpoint_IsTerraformResource(x interface{}) *bool
Experimental.
func VectorSearchEndpoint_TfResourceType ¶
func VectorSearchEndpoint_TfResourceType() *string
Types ¶
type VectorSearchEndpoint ¶
type VectorSearchEndpoint interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CreationTimestamp() *float64
Creator() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
EndpointId() *string
EndpointStatus() VectorSearchEndpointEndpointStatusList
EndpointType() *string
SetEndpointType(val *string)
EndpointTypeInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
LastUpdatedTimestamp() *float64
LastUpdatedUser() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
NumIndexes() *float64
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() VectorSearchEndpointTimeoutsOutputReference
TimeoutsInput() interface{}
// Adds a user defined moveTarget string to this resource to be later used in .moveTo(moveTarget) to resolve the location of the move.
// Experimental.
AddMoveTarget(moveTarget *string)
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
HasResourceMove() interface{}
// Experimental.
ImportFrom(id *string, provider cdktf.TerraformProvider)
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Move the resource corresponding to "id" to this resource.
//
// Note that the resource being moved from must be marked as moved using it's instance function.
// Experimental.
MoveFromId(id *string)
// Moves this resource to the target resource given by moveTarget.
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Moves this resource to the resource corresponding to "id".
// Experimental.
MoveToId(id *string)
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutTimeouts(value *VectorSearchEndpointTimeouts)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
SynthesizeHclAttributes() *map[string]interface{}
// Experimental.
ToHclTerraform() interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/vector_search_endpoint databricks_vector_search_endpoint}.
func NewVectorSearchEndpoint ¶
func NewVectorSearchEndpoint(scope constructs.Construct, id *string, config *VectorSearchEndpointConfig) VectorSearchEndpoint
Create a new {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/vector_search_endpoint databricks_vector_search_endpoint} Resource.
type VectorSearchEndpointConfig ¶
type VectorSearchEndpointConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/vector_search_endpoint#endpoint_type VectorSearchEndpoint#endpoint_type}.
EndpointType *string `field:"required" json:"endpointType" yaml:"endpointType"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/vector_search_endpoint#name VectorSearchEndpoint#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/vector_search_endpoint#id VectorSearchEndpoint#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/vector_search_endpoint#timeouts VectorSearchEndpoint#timeouts}
Timeouts *VectorSearchEndpointTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type VectorSearchEndpointEndpointStatus ¶
type VectorSearchEndpointEndpointStatus struct {
}
type VectorSearchEndpointEndpointStatusList ¶
type VectorSearchEndpointEndpointStatusList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) VectorSearchEndpointEndpointStatusOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewVectorSearchEndpointEndpointStatusList ¶
func NewVectorSearchEndpointEndpointStatusList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) VectorSearchEndpointEndpointStatusList
type VectorSearchEndpointEndpointStatusOutputReference ¶
type VectorSearchEndpointEndpointStatusOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *VectorSearchEndpointEndpointStatus
SetInternalValue(val *VectorSearchEndpointEndpointStatus)
Message() *string
State() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewVectorSearchEndpointEndpointStatusOutputReference ¶
func NewVectorSearchEndpointEndpointStatusOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) VectorSearchEndpointEndpointStatusOutputReference
type VectorSearchEndpointTimeouts ¶
type VectorSearchEndpointTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/vector_search_endpoint#create VectorSearchEndpoint#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
}
type VectorSearchEndpointTimeoutsOutputReference ¶
type VectorSearchEndpointTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewVectorSearchEndpointTimeoutsOutputReference ¶
func NewVectorSearchEndpointTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) VectorSearchEndpointTimeoutsOutputReference
Source Files
¶
- VectorSearchEndpoint.go
- VectorSearchEndpointConfig.go
- VectorSearchEndpointEndpointStatus.go
- VectorSearchEndpointEndpointStatusList.go
- VectorSearchEndpointEndpointStatusList__checks.go
- VectorSearchEndpointEndpointStatusOutputReference.go
- VectorSearchEndpointEndpointStatusOutputReference__checks.go
- VectorSearchEndpointTimeouts.go
- VectorSearchEndpointTimeoutsOutputReference.go
- VectorSearchEndpointTimeoutsOutputReference__checks.go
- VectorSearchEndpoint__checks.go
- main.go