Documentation
¶
Index ¶
- func NewVectorSearchIndexDeltaSyncIndexSpecEmbeddingSourceColumnsList_Override(v VectorSearchIndexDeltaSyncIndexSpecEmbeddingSourceColumnsList, ...)
- func NewVectorSearchIndexDeltaSyncIndexSpecEmbeddingSourceColumnsOutputReference_Override(v VectorSearchIndexDeltaSyncIndexSpecEmbeddingSourceColumnsOutputReference, ...)
- func NewVectorSearchIndexDeltaSyncIndexSpecEmbeddingVectorColumnsList_Override(v VectorSearchIndexDeltaSyncIndexSpecEmbeddingVectorColumnsList, ...)
- func NewVectorSearchIndexDeltaSyncIndexSpecEmbeddingVectorColumnsOutputReference_Override(v VectorSearchIndexDeltaSyncIndexSpecEmbeddingVectorColumnsOutputReference, ...)
- func NewVectorSearchIndexDeltaSyncIndexSpecOutputReference_Override(v VectorSearchIndexDeltaSyncIndexSpecOutputReference, ...)
- func NewVectorSearchIndexDirectAccessIndexSpecEmbeddingSourceColumnsList_Override(v VectorSearchIndexDirectAccessIndexSpecEmbeddingSourceColumnsList, ...)
- func NewVectorSearchIndexDirectAccessIndexSpecEmbeddingSourceColumnsOutputReference_Override(v VectorSearchIndexDirectAccessIndexSpecEmbeddingSourceColumnsOutputReference, ...)
- func NewVectorSearchIndexDirectAccessIndexSpecEmbeddingVectorColumnsList_Override(v VectorSearchIndexDirectAccessIndexSpecEmbeddingVectorColumnsList, ...)
- func NewVectorSearchIndexDirectAccessIndexSpecEmbeddingVectorColumnsOutputReference_Override(v VectorSearchIndexDirectAccessIndexSpecEmbeddingVectorColumnsOutputReference, ...)
- func NewVectorSearchIndexDirectAccessIndexSpecOutputReference_Override(v VectorSearchIndexDirectAccessIndexSpecOutputReference, ...)
- func NewVectorSearchIndexStatusList_Override(v VectorSearchIndexStatusList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewVectorSearchIndexStatusOutputReference_Override(v VectorSearchIndexStatusOutputReference, ...)
- func NewVectorSearchIndexTimeoutsOutputReference_Override(v VectorSearchIndexTimeoutsOutputReference, ...)
- func NewVectorSearchIndex_Override(v VectorSearchIndex, scope constructs.Construct, id *string, ...)
- func VectorSearchIndex_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func VectorSearchIndex_IsConstruct(x interface{}) *bool
- func VectorSearchIndex_IsTerraformElement(x interface{}) *bool
- func VectorSearchIndex_IsTerraformResource(x interface{}) *bool
- func VectorSearchIndex_TfResourceType() *string
- type VectorSearchIndex
- type VectorSearchIndexConfig
- type VectorSearchIndexDeltaSyncIndexSpec
- type VectorSearchIndexDeltaSyncIndexSpecEmbeddingSourceColumns
- type VectorSearchIndexDeltaSyncIndexSpecEmbeddingSourceColumnsList
- type VectorSearchIndexDeltaSyncIndexSpecEmbeddingSourceColumnsOutputReference
- type VectorSearchIndexDeltaSyncIndexSpecEmbeddingVectorColumns
- type VectorSearchIndexDeltaSyncIndexSpecEmbeddingVectorColumnsList
- type VectorSearchIndexDeltaSyncIndexSpecEmbeddingVectorColumnsOutputReference
- type VectorSearchIndexDeltaSyncIndexSpecOutputReference
- type VectorSearchIndexDirectAccessIndexSpec
- type VectorSearchIndexDirectAccessIndexSpecEmbeddingSourceColumns
- type VectorSearchIndexDirectAccessIndexSpecEmbeddingSourceColumnsList
- type VectorSearchIndexDirectAccessIndexSpecEmbeddingSourceColumnsOutputReference
- type VectorSearchIndexDirectAccessIndexSpecEmbeddingVectorColumns
- type VectorSearchIndexDirectAccessIndexSpecEmbeddingVectorColumnsList
- type VectorSearchIndexDirectAccessIndexSpecEmbeddingVectorColumnsOutputReference
- type VectorSearchIndexDirectAccessIndexSpecOutputReference
- type VectorSearchIndexStatus
- type VectorSearchIndexStatusList
- type VectorSearchIndexStatusOutputReference
- type VectorSearchIndexTimeouts
- type VectorSearchIndexTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewVectorSearchIndexDeltaSyncIndexSpecEmbeddingSourceColumnsList_Override ¶
func NewVectorSearchIndexDeltaSyncIndexSpecEmbeddingSourceColumnsList_Override(v VectorSearchIndexDeltaSyncIndexSpecEmbeddingSourceColumnsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewVectorSearchIndexDeltaSyncIndexSpecEmbeddingSourceColumnsOutputReference_Override ¶
func NewVectorSearchIndexDeltaSyncIndexSpecEmbeddingSourceColumnsOutputReference_Override(v VectorSearchIndexDeltaSyncIndexSpecEmbeddingSourceColumnsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewVectorSearchIndexDeltaSyncIndexSpecEmbeddingVectorColumnsList_Override ¶
func NewVectorSearchIndexDeltaSyncIndexSpecEmbeddingVectorColumnsList_Override(v VectorSearchIndexDeltaSyncIndexSpecEmbeddingVectorColumnsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewVectorSearchIndexDeltaSyncIndexSpecEmbeddingVectorColumnsOutputReference_Override ¶
func NewVectorSearchIndexDeltaSyncIndexSpecEmbeddingVectorColumnsOutputReference_Override(v VectorSearchIndexDeltaSyncIndexSpecEmbeddingVectorColumnsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewVectorSearchIndexDeltaSyncIndexSpecOutputReference_Override ¶
func NewVectorSearchIndexDeltaSyncIndexSpecOutputReference_Override(v VectorSearchIndexDeltaSyncIndexSpecOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewVectorSearchIndexDirectAccessIndexSpecEmbeddingSourceColumnsList_Override ¶
func NewVectorSearchIndexDirectAccessIndexSpecEmbeddingSourceColumnsList_Override(v VectorSearchIndexDirectAccessIndexSpecEmbeddingSourceColumnsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewVectorSearchIndexDirectAccessIndexSpecEmbeddingSourceColumnsOutputReference_Override ¶
func NewVectorSearchIndexDirectAccessIndexSpecEmbeddingSourceColumnsOutputReference_Override(v VectorSearchIndexDirectAccessIndexSpecEmbeddingSourceColumnsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewVectorSearchIndexDirectAccessIndexSpecEmbeddingVectorColumnsList_Override ¶
func NewVectorSearchIndexDirectAccessIndexSpecEmbeddingVectorColumnsList_Override(v VectorSearchIndexDirectAccessIndexSpecEmbeddingVectorColumnsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewVectorSearchIndexDirectAccessIndexSpecEmbeddingVectorColumnsOutputReference_Override ¶
func NewVectorSearchIndexDirectAccessIndexSpecEmbeddingVectorColumnsOutputReference_Override(v VectorSearchIndexDirectAccessIndexSpecEmbeddingVectorColumnsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewVectorSearchIndexDirectAccessIndexSpecOutputReference_Override ¶
func NewVectorSearchIndexDirectAccessIndexSpecOutputReference_Override(v VectorSearchIndexDirectAccessIndexSpecOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewVectorSearchIndexStatusList_Override ¶
func NewVectorSearchIndexStatusList_Override(v VectorSearchIndexStatusList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewVectorSearchIndexStatusOutputReference_Override ¶
func NewVectorSearchIndexStatusOutputReference_Override(v VectorSearchIndexStatusOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewVectorSearchIndexTimeoutsOutputReference_Override ¶
func NewVectorSearchIndexTimeoutsOutputReference_Override(v VectorSearchIndexTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewVectorSearchIndex_Override ¶
func NewVectorSearchIndex_Override(v VectorSearchIndex, scope constructs.Construct, id *string, config *VectorSearchIndexConfig)
Create a new {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/vector_search_index databricks_vector_search_index} Resource.
func VectorSearchIndex_GenerateConfigForImport ¶
func VectorSearchIndex_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a VectorSearchIndex resource upon running "cdktf plan <stack-name>".
func VectorSearchIndex_IsConstruct ¶
func VectorSearchIndex_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func VectorSearchIndex_IsTerraformElement ¶
func VectorSearchIndex_IsTerraformElement(x interface{}) *bool
Experimental.
func VectorSearchIndex_IsTerraformResource ¶
func VectorSearchIndex_IsTerraformResource(x interface{}) *bool
Experimental.
func VectorSearchIndex_TfResourceType ¶
func VectorSearchIndex_TfResourceType() *string
Types ¶
type VectorSearchIndex ¶
type VectorSearchIndex interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
Creator() *string
DeltaSyncIndexSpec() VectorSearchIndexDeltaSyncIndexSpecOutputReference
DeltaSyncIndexSpecInput() *VectorSearchIndexDeltaSyncIndexSpec
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DirectAccessIndexSpec() VectorSearchIndexDirectAccessIndexSpecOutputReference
DirectAccessIndexSpecInput() *VectorSearchIndexDirectAccessIndexSpec
EndpointName() *string
SetEndpointName(val *string)
EndpointNameInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
IndexType() *string
SetIndexType(val *string)
IndexTypeInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
PrimaryKey() *string
SetPrimaryKey(val *string)
PrimaryKeyInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Status() VectorSearchIndexStatusList
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() VectorSearchIndexTimeoutsOutputReference
TimeoutsInput() interface{}
// Adds a user defined moveTarget string to this resource to be later used in .moveTo(moveTarget) to resolve the location of the move.
// Experimental.
AddMoveTarget(moveTarget *string)
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
HasResourceMove() interface{}
// Experimental.
ImportFrom(id *string, provider cdktf.TerraformProvider)
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Move the resource corresponding to "id" to this resource.
//
// Note that the resource being moved from must be marked as moved using it's instance function.
// Experimental.
MoveFromId(id *string)
// Moves this resource to the target resource given by moveTarget.
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Moves this resource to the resource corresponding to "id".
// Experimental.
MoveToId(id *string)
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutDeltaSyncIndexSpec(value *VectorSearchIndexDeltaSyncIndexSpec)
PutDirectAccessIndexSpec(value *VectorSearchIndexDirectAccessIndexSpec)
PutTimeouts(value *VectorSearchIndexTimeouts)
ResetDeltaSyncIndexSpec()
ResetDirectAccessIndexSpec()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
SynthesizeHclAttributes() *map[string]interface{}
// Experimental.
ToHclTerraform() interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/vector_search_index databricks_vector_search_index}.
func NewVectorSearchIndex ¶
func NewVectorSearchIndex(scope constructs.Construct, id *string, config *VectorSearchIndexConfig) VectorSearchIndex
Create a new {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/vector_search_index databricks_vector_search_index} Resource.
type VectorSearchIndexConfig ¶
type VectorSearchIndexConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/vector_search_index#endpoint_name VectorSearchIndex#endpoint_name}.
EndpointName *string `field:"required" json:"endpointName" yaml:"endpointName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/vector_search_index#index_type VectorSearchIndex#index_type}.
IndexType *string `field:"required" json:"indexType" yaml:"indexType"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/vector_search_index#name VectorSearchIndex#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/vector_search_index#primary_key VectorSearchIndex#primary_key}.
PrimaryKey *string `field:"required" json:"primaryKey" yaml:"primaryKey"`
// delta_sync_index_spec block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/vector_search_index#delta_sync_index_spec VectorSearchIndex#delta_sync_index_spec}
DeltaSyncIndexSpec *VectorSearchIndexDeltaSyncIndexSpec `field:"optional" json:"deltaSyncIndexSpec" yaml:"deltaSyncIndexSpec"`
// direct_access_index_spec block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/vector_search_index#direct_access_index_spec VectorSearchIndex#direct_access_index_spec}
DirectAccessIndexSpec *VectorSearchIndexDirectAccessIndexSpec `field:"optional" json:"directAccessIndexSpec" yaml:"directAccessIndexSpec"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/vector_search_index#id VectorSearchIndex#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/vector_search_index#timeouts VectorSearchIndex#timeouts}
Timeouts *VectorSearchIndexTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type VectorSearchIndexDeltaSyncIndexSpec ¶
type VectorSearchIndexDeltaSyncIndexSpec struct {
// embedding_source_columns block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/vector_search_index#embedding_source_columns VectorSearchIndex#embedding_source_columns}
EmbeddingSourceColumns interface{} `field:"optional" json:"embeddingSourceColumns" yaml:"embeddingSourceColumns"`
// embedding_vector_columns block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/vector_search_index#embedding_vector_columns VectorSearchIndex#embedding_vector_columns}
EmbeddingVectorColumns interface{} `field:"optional" json:"embeddingVectorColumns" yaml:"embeddingVectorColumns"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/vector_search_index#embedding_writeback_table VectorSearchIndex#embedding_writeback_table}.
EmbeddingWritebackTable *string `field:"optional" json:"embeddingWritebackTable" yaml:"embeddingWritebackTable"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/vector_search_index#pipeline_type VectorSearchIndex#pipeline_type}.
PipelineType *string `field:"optional" json:"pipelineType" yaml:"pipelineType"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/vector_search_index#source_table VectorSearchIndex#source_table}.
SourceTable *string `field:"optional" json:"sourceTable" yaml:"sourceTable"`
}
type VectorSearchIndexDeltaSyncIndexSpecEmbeddingSourceColumns ¶
type VectorSearchIndexDeltaSyncIndexSpecEmbeddingSourceColumns struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/vector_search_index#embedding_model_endpoint_name VectorSearchIndex#embedding_model_endpoint_name}.
EmbeddingModelEndpointName *string `field:"optional" json:"embeddingModelEndpointName" yaml:"embeddingModelEndpointName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/vector_search_index#name VectorSearchIndex#name}.
Name *string `field:"optional" json:"name" yaml:"name"`
}
type VectorSearchIndexDeltaSyncIndexSpecEmbeddingSourceColumnsList ¶
type VectorSearchIndexDeltaSyncIndexSpecEmbeddingSourceColumnsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) VectorSearchIndexDeltaSyncIndexSpecEmbeddingSourceColumnsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewVectorSearchIndexDeltaSyncIndexSpecEmbeddingSourceColumnsList ¶
func NewVectorSearchIndexDeltaSyncIndexSpecEmbeddingSourceColumnsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) VectorSearchIndexDeltaSyncIndexSpecEmbeddingSourceColumnsList
type VectorSearchIndexDeltaSyncIndexSpecEmbeddingSourceColumnsOutputReference ¶
type VectorSearchIndexDeltaSyncIndexSpecEmbeddingSourceColumnsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EmbeddingModelEndpointName() *string
SetEmbeddingModelEndpointName(val *string)
EmbeddingModelEndpointNameInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Name() *string
SetName(val *string)
NameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetEmbeddingModelEndpointName()
ResetName()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewVectorSearchIndexDeltaSyncIndexSpecEmbeddingSourceColumnsOutputReference ¶
func NewVectorSearchIndexDeltaSyncIndexSpecEmbeddingSourceColumnsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) VectorSearchIndexDeltaSyncIndexSpecEmbeddingSourceColumnsOutputReference
type VectorSearchIndexDeltaSyncIndexSpecEmbeddingVectorColumns ¶
type VectorSearchIndexDeltaSyncIndexSpecEmbeddingVectorColumns struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/vector_search_index#embedding_dimension VectorSearchIndex#embedding_dimension}.
EmbeddingDimension *float64 `field:"optional" json:"embeddingDimension" yaml:"embeddingDimension"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/vector_search_index#name VectorSearchIndex#name}.
Name *string `field:"optional" json:"name" yaml:"name"`
}
type VectorSearchIndexDeltaSyncIndexSpecEmbeddingVectorColumnsList ¶
type VectorSearchIndexDeltaSyncIndexSpecEmbeddingVectorColumnsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) VectorSearchIndexDeltaSyncIndexSpecEmbeddingVectorColumnsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewVectorSearchIndexDeltaSyncIndexSpecEmbeddingVectorColumnsList ¶
func NewVectorSearchIndexDeltaSyncIndexSpecEmbeddingVectorColumnsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) VectorSearchIndexDeltaSyncIndexSpecEmbeddingVectorColumnsList
type VectorSearchIndexDeltaSyncIndexSpecEmbeddingVectorColumnsOutputReference ¶
type VectorSearchIndexDeltaSyncIndexSpecEmbeddingVectorColumnsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EmbeddingDimension() *float64
SetEmbeddingDimension(val *float64)
EmbeddingDimensionInput() *float64
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Name() *string
SetName(val *string)
NameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetEmbeddingDimension()
ResetName()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewVectorSearchIndexDeltaSyncIndexSpecEmbeddingVectorColumnsOutputReference ¶
func NewVectorSearchIndexDeltaSyncIndexSpecEmbeddingVectorColumnsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) VectorSearchIndexDeltaSyncIndexSpecEmbeddingVectorColumnsOutputReference
type VectorSearchIndexDeltaSyncIndexSpecOutputReference ¶
type VectorSearchIndexDeltaSyncIndexSpecOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EmbeddingSourceColumns() VectorSearchIndexDeltaSyncIndexSpecEmbeddingSourceColumnsList
EmbeddingSourceColumnsInput() interface{}
EmbeddingVectorColumns() VectorSearchIndexDeltaSyncIndexSpecEmbeddingVectorColumnsList
EmbeddingVectorColumnsInput() interface{}
EmbeddingWritebackTable() *string
SetEmbeddingWritebackTable(val *string)
EmbeddingWritebackTableInput() *string
// Experimental.
Fqn() *string
InternalValue() *VectorSearchIndexDeltaSyncIndexSpec
SetInternalValue(val *VectorSearchIndexDeltaSyncIndexSpec)
PipelineId() *string
PipelineType() *string
SetPipelineType(val *string)
PipelineTypeInput() *string
SourceTable() *string
SetSourceTable(val *string)
SourceTableInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutEmbeddingSourceColumns(value interface{})
PutEmbeddingVectorColumns(value interface{})
ResetEmbeddingSourceColumns()
ResetEmbeddingVectorColumns()
ResetEmbeddingWritebackTable()
ResetPipelineType()
ResetSourceTable()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewVectorSearchIndexDeltaSyncIndexSpecOutputReference ¶
func NewVectorSearchIndexDeltaSyncIndexSpecOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) VectorSearchIndexDeltaSyncIndexSpecOutputReference
type VectorSearchIndexDirectAccessIndexSpec ¶
type VectorSearchIndexDirectAccessIndexSpec struct {
// embedding_source_columns block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/vector_search_index#embedding_source_columns VectorSearchIndex#embedding_source_columns}
EmbeddingSourceColumns interface{} `field:"optional" json:"embeddingSourceColumns" yaml:"embeddingSourceColumns"`
// embedding_vector_columns block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/vector_search_index#embedding_vector_columns VectorSearchIndex#embedding_vector_columns}
EmbeddingVectorColumns interface{} `field:"optional" json:"embeddingVectorColumns" yaml:"embeddingVectorColumns"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/vector_search_index#schema_json VectorSearchIndex#schema_json}.
SchemaJson *string `field:"optional" json:"schemaJson" yaml:"schemaJson"`
}
type VectorSearchIndexDirectAccessIndexSpecEmbeddingSourceColumns ¶
type VectorSearchIndexDirectAccessIndexSpecEmbeddingSourceColumns struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/vector_search_index#embedding_model_endpoint_name VectorSearchIndex#embedding_model_endpoint_name}.
EmbeddingModelEndpointName *string `field:"optional" json:"embeddingModelEndpointName" yaml:"embeddingModelEndpointName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/vector_search_index#name VectorSearchIndex#name}.
Name *string `field:"optional" json:"name" yaml:"name"`
}
type VectorSearchIndexDirectAccessIndexSpecEmbeddingSourceColumnsList ¶
type VectorSearchIndexDirectAccessIndexSpecEmbeddingSourceColumnsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) VectorSearchIndexDirectAccessIndexSpecEmbeddingSourceColumnsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewVectorSearchIndexDirectAccessIndexSpecEmbeddingSourceColumnsList ¶
func NewVectorSearchIndexDirectAccessIndexSpecEmbeddingSourceColumnsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) VectorSearchIndexDirectAccessIndexSpecEmbeddingSourceColumnsList
type VectorSearchIndexDirectAccessIndexSpecEmbeddingSourceColumnsOutputReference ¶
type VectorSearchIndexDirectAccessIndexSpecEmbeddingSourceColumnsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EmbeddingModelEndpointName() *string
SetEmbeddingModelEndpointName(val *string)
EmbeddingModelEndpointNameInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Name() *string
SetName(val *string)
NameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetEmbeddingModelEndpointName()
ResetName()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewVectorSearchIndexDirectAccessIndexSpecEmbeddingSourceColumnsOutputReference ¶
func NewVectorSearchIndexDirectAccessIndexSpecEmbeddingSourceColumnsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) VectorSearchIndexDirectAccessIndexSpecEmbeddingSourceColumnsOutputReference
type VectorSearchIndexDirectAccessIndexSpecEmbeddingVectorColumns ¶
type VectorSearchIndexDirectAccessIndexSpecEmbeddingVectorColumns struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/vector_search_index#embedding_dimension VectorSearchIndex#embedding_dimension}.
EmbeddingDimension *float64 `field:"optional" json:"embeddingDimension" yaml:"embeddingDimension"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/vector_search_index#name VectorSearchIndex#name}.
Name *string `field:"optional" json:"name" yaml:"name"`
}
type VectorSearchIndexDirectAccessIndexSpecEmbeddingVectorColumnsList ¶
type VectorSearchIndexDirectAccessIndexSpecEmbeddingVectorColumnsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) VectorSearchIndexDirectAccessIndexSpecEmbeddingVectorColumnsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewVectorSearchIndexDirectAccessIndexSpecEmbeddingVectorColumnsList ¶
func NewVectorSearchIndexDirectAccessIndexSpecEmbeddingVectorColumnsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) VectorSearchIndexDirectAccessIndexSpecEmbeddingVectorColumnsList
type VectorSearchIndexDirectAccessIndexSpecEmbeddingVectorColumnsOutputReference ¶
type VectorSearchIndexDirectAccessIndexSpecEmbeddingVectorColumnsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EmbeddingDimension() *float64
SetEmbeddingDimension(val *float64)
EmbeddingDimensionInput() *float64
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Name() *string
SetName(val *string)
NameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetEmbeddingDimension()
ResetName()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewVectorSearchIndexDirectAccessIndexSpecEmbeddingVectorColumnsOutputReference ¶
func NewVectorSearchIndexDirectAccessIndexSpecEmbeddingVectorColumnsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) VectorSearchIndexDirectAccessIndexSpecEmbeddingVectorColumnsOutputReference
type VectorSearchIndexDirectAccessIndexSpecOutputReference ¶
type VectorSearchIndexDirectAccessIndexSpecOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EmbeddingSourceColumns() VectorSearchIndexDirectAccessIndexSpecEmbeddingSourceColumnsList
EmbeddingSourceColumnsInput() interface{}
EmbeddingVectorColumns() VectorSearchIndexDirectAccessIndexSpecEmbeddingVectorColumnsList
EmbeddingVectorColumnsInput() interface{}
// Experimental.
Fqn() *string
InternalValue() *VectorSearchIndexDirectAccessIndexSpec
SetInternalValue(val *VectorSearchIndexDirectAccessIndexSpec)
SchemaJson() *string
SetSchemaJson(val *string)
SchemaJsonInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutEmbeddingSourceColumns(value interface{})
PutEmbeddingVectorColumns(value interface{})
ResetEmbeddingSourceColumns()
ResetEmbeddingVectorColumns()
ResetSchemaJson()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewVectorSearchIndexDirectAccessIndexSpecOutputReference ¶
func NewVectorSearchIndexDirectAccessIndexSpecOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) VectorSearchIndexDirectAccessIndexSpecOutputReference
type VectorSearchIndexStatus ¶
type VectorSearchIndexStatus struct {
}
type VectorSearchIndexStatusList ¶
type VectorSearchIndexStatusList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) VectorSearchIndexStatusOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewVectorSearchIndexStatusList ¶
func NewVectorSearchIndexStatusList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) VectorSearchIndexStatusList
type VectorSearchIndexStatusOutputReference ¶
type VectorSearchIndexStatusOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
IndexedRowCount() *float64
IndexUrl() *string
InternalValue() *VectorSearchIndexStatus
SetInternalValue(val *VectorSearchIndexStatus)
Message() *string
Ready() cdktf.IResolvable
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewVectorSearchIndexStatusOutputReference ¶
func NewVectorSearchIndexStatusOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) VectorSearchIndexStatusOutputReference
type VectorSearchIndexTimeouts ¶
type VectorSearchIndexTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.51.0/docs/resources/vector_search_index#create VectorSearchIndex#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
}
type VectorSearchIndexTimeoutsOutputReference ¶
type VectorSearchIndexTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewVectorSearchIndexTimeoutsOutputReference ¶
func NewVectorSearchIndexTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) VectorSearchIndexTimeoutsOutputReference
Source Files
¶
- VectorSearchIndex.go
- VectorSearchIndexConfig.go
- VectorSearchIndexDeltaSyncIndexSpec.go
- VectorSearchIndexDeltaSyncIndexSpecEmbeddingSourceColumns.go
- VectorSearchIndexDeltaSyncIndexSpecEmbeddingSourceColumnsList.go
- VectorSearchIndexDeltaSyncIndexSpecEmbeddingSourceColumnsList__checks.go
- VectorSearchIndexDeltaSyncIndexSpecEmbeddingSourceColumnsOutputReference.go
- VectorSearchIndexDeltaSyncIndexSpecEmbeddingSourceColumnsOutputReference__checks.go
- VectorSearchIndexDeltaSyncIndexSpecEmbeddingVectorColumns.go
- VectorSearchIndexDeltaSyncIndexSpecEmbeddingVectorColumnsList.go
- VectorSearchIndexDeltaSyncIndexSpecEmbeddingVectorColumnsList__checks.go
- VectorSearchIndexDeltaSyncIndexSpecEmbeddingVectorColumnsOutputReference.go
- VectorSearchIndexDeltaSyncIndexSpecEmbeddingVectorColumnsOutputReference__checks.go
- VectorSearchIndexDeltaSyncIndexSpecOutputReference.go
- VectorSearchIndexDeltaSyncIndexSpecOutputReference__checks.go
- VectorSearchIndexDirectAccessIndexSpec.go
- VectorSearchIndexDirectAccessIndexSpecEmbeddingSourceColumns.go
- VectorSearchIndexDirectAccessIndexSpecEmbeddingSourceColumnsList.go
- VectorSearchIndexDirectAccessIndexSpecEmbeddingSourceColumnsList__checks.go
- VectorSearchIndexDirectAccessIndexSpecEmbeddingSourceColumnsOutputReference.go
- VectorSearchIndexDirectAccessIndexSpecEmbeddingSourceColumnsOutputReference__checks.go
- VectorSearchIndexDirectAccessIndexSpecEmbeddingVectorColumns.go
- VectorSearchIndexDirectAccessIndexSpecEmbeddingVectorColumnsList.go
- VectorSearchIndexDirectAccessIndexSpecEmbeddingVectorColumnsList__checks.go
- VectorSearchIndexDirectAccessIndexSpecEmbeddingVectorColumnsOutputReference.go
- VectorSearchIndexDirectAccessIndexSpecEmbeddingVectorColumnsOutputReference__checks.go
- VectorSearchIndexDirectAccessIndexSpecOutputReference.go
- VectorSearchIndexDirectAccessIndexSpecOutputReference__checks.go
- VectorSearchIndexStatus.go
- VectorSearchIndexStatusList.go
- VectorSearchIndexStatusList__checks.go
- VectorSearchIndexStatusOutputReference.go
- VectorSearchIndexStatusOutputReference__checks.go
- VectorSearchIndexTimeouts.go
- VectorSearchIndexTimeoutsOutputReference.go
- VectorSearchIndexTimeoutsOutputReference__checks.go
- VectorSearchIndex__checks.go
- main.go